function [B IND]=var_select(gamma,C,A,y,command)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  gene selection by RLS-SVR
%  input: 
%   gamma: the parameter for Gaussian kernel transformation
%   C: the parameter for RLS-SVR
%   A, y: input data
%   command: option: 
%      -t: selected times, maximum and default is 2
%      -q: size of candidate subset, default is 10
%      -r: size of intermediate candidate subset, default is 10*q
% output:
%   B: the decreasing weighted expression sums
%   IND: indices of selected genes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[rx cx]=size(A);
stdx=(A-mean(A,2)*ones(1,cx))./(std(A,1,2)*ones(1,cx));% standardization
% setting fedault 
select_times=2; subset_size=10; inter_size=10*subset_size;
if (exist('command'))
    [pInd, pVal] = strread(command, '%s%f', 'delimiter', ' ');
    for i=1:length(pInd)  
        if(strcmp(pInd{i}, '-t'))  
            select_times= pVal(i); 
        elseif(strcmp(pInd{i}, '-q'))  
            subset_size = pVal(i);% model selection method
        elseif(strcmp(pInd{i}, '-r'))  
           inter_size = pVal(i);% ratio of reduced set to full set
        else
            error('undefined parameter: %s', pVal(i));
        end
    end
end
if (select_times>2 || select_times<1)
    error('The selecting times must be 1 or 2')
end
IND=[1:cx];
kr=KGaussian (gamma,stdx,stdx);  
[rx cx]=size(kr);
w0=zeros(cx,1); b0=0;
[w b] = zerossvr_mtrx(kr,y,w0,b0,C);
[B1 IX1] = sort(abs(w'*stdx),'descend');
IND=IND(IX1);
if select_times==1
    A1=stdx(:,IX1(1:subset_size));
    kr1=KGaussian(gamma,A1,A1);
    [w b] = zerossvr_mtrx(kr1,y,w0,b0,C);
    [B IX] = sort(abs(w'*A1),'descend');
    IND=IND(IX);
end
if select_times==2
    A1=stdx(:,IX1(1:inter_size));
    kr1=KGaussian(gamma,A1,A1);
    [w b] = zerossvr_mtrx(kr1,y,w0,b0,C);
    [B2 IX2] = sort(abs(w'*A1),'descend');
    IND=IND(IX2);
    A2=A1(:,IX2(1:subset_size));
    kr2=KGaussian(gamma,A2,A2);
    [w b] = zerossvr_mtrx(kr2,y,w0,b0,C);
    [B IX]=sort(abs(w'*A2),'descend');
    IND=IND(IX);
end
    

