function [w,b] = zerossvr_mtrx(A, y, w0,b0,C)

%#####################################################################
%#                                                                   #
%# Input data                                                        #
%#   A: Training data                                                #
%#   y: response, can be multivariate                                #
%#   [w0; b0]: Initial point                                         #
%#   C: Weighted parameter                                           #                                 #
%#                                                                   #
%# Output                                                            #
%#  w: regression coefficients                                       #
%#  b: the intercept                                                 #
%#####################################################################
[row_A column_A]=size(A);

e = ones(row_A,1);
flag = 1;
T = speye(column_A+1);
q = A'*e;
hessian = T+C*[A'*A , q  ; q' , e'*e];

while flag > 1E-4
     h=C*(y-A*w0-e*b0);
     gradient = [w0-A'*h ; b0-e'*h];
     
     if (norm(gradient)/sqrt(column_A) > 1E-5)       
        z = hessian\(-gradient);  % descent direction
        w0 = w0 + z(1:column_A,:);
        b0 = b0 + z(column_A+1,:);
               
        flag = norm(z);
     else   
         flag = 0;
     end
 end     
 w=w0;
 b=b0;
%=====================================================================
